import 'package:flutter/material.dart';

/// RouteAnimation package will help you to create good looking
/// transition animation between your pages with a simple call

/// Available animation types
enum AnimationType {
  normal,
  fadeIn,
}

/// Main class
/// [BuildContext] is required to perform a transition
/// using the animation type to animate the child into a new route.
/// [replacement] will remove all the stack of pages into a new route
class RouteTransitionDo {
  final BuildContext context;
  final AnimationType animationType;
  final Widget child;
  final bool replacement;
  final Duration duration;

  RouteTransitionDo({
    @required this.context,
    @required this.child,
    this.replacement = false,
    this.animationType = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
  }) {
    switch (this.animationType) {
      case AnimationType.normal:
        _normalTransition();
        break;

      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
    }
  }

  /// Push the new page into the stack of pages
  void _pushPage(Route route) => Navigator.push(context, route);

  /// Replace the stack of pages
  void _pushReplacement(Route route) =>
      Navigator.pushReplacement(context, route);

  /// Basic transition animation
  void _normalTransition() =>
      Navigator.push(context, MaterialPageRoute(builder: (_) => this.child));

  /// FadeInAnimation Handler
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => child,
        transitionDuration: this.duration,
        transitionsBuilder: (context, animation, _, child) {
          return FadeTransition(
              child: child,
              opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                  CurvedAnimation(parent: animation, curve: Curves.easeOut)));
        });

    (this.replacement) ? this._pushReplacement(route) : this._pushPage(route);
  }
}
